aboutsummaryrefslogtreecommitdiff
path: root/ef-spring-theme.el
diff options
context:
space:
mode:
authorProtesilaos Stavrou <info@protesilaos.com>2022-09-07 06:19:10 +0300
committerProtesilaos Stavrou <info@protesilaos.com>2022-09-07 06:19:10 +0300
commitc11d7b767134be9a7b91453e2792fe009c7529b7 (patch)
tree85207f0378436a6cbec1c52087acdca500418e88 /ef-spring-theme.el
parent0416ea8554a78e8ae352fb314a336672b048d41c (diff)
Make theme one-line descriptions more descriptive
Diffstat (limited to 'ef-spring-theme.el')
-rw-r--r--ef-spring-theme.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/ef-spring-theme.el b/ef-spring-theme.el
index 54e3949..48c3b6b 100644
--- a/ef-spring-theme.el
+++ b/ef-spring-theme.el
@@ -1,4 +1,4 @@
;;; ef-spring-theme.el --- Legible light theme with cool, green, red colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-spring "Legible light theme with cool, green, red colors.")
+ (deftheme ef-spring "Legible light theme with cool, varied colors (green, cyan, red).")
(defconst ef-spring-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-spring-theme.el --- Legible light theme with cool, green, red colors -*- lexical-binding:t -*-
+;;; ef-spring-theme.el --- Legible light theme with cool, varied colors (green, cyan, red) -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.